@@ -30,7 +30,6 @@
 
 /**
  * SECTION: qmi-enums-wms
- * @title: WMS enumerations and flags
  *
  * This section defines enumerations and flags used in the WMS service
  * interface.
@@ -49,18 +48,12 @@
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_STORAGE_TYPE_UIM  = 0x00,
     QMI_WMS_STORAGE_TYPE_NV   = 0x01,
     QMI_WMS_STORAGE_TYPE_NONE = 0xFF
 } QmiWmsStorageType;
 
-/**
- * qmi_wms_storage_type_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsAckIndicator:
  * @QMI_WMS_ACK_INDICATOR_SEND: ACK needs to be sent.
@@ -70,17 +63,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_ACK_INDICATOR_SEND        = 0x00,
     QMI_WMS_ACK_INDICATOR_DO_NOT_SEND = 0x01
 } QmiWmsAckIndicator;
 
-/**
- * qmi_wms_ack_indicator_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsMessageFormat:
  * @QMI_WMS_MESSAGE_FORMAT_CDMA: CDMA message.
@@ -92,19 +79,13 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_FORMAT_CDMA                     = 0x00,
     QMI_WMS_MESSAGE_FORMAT_GSM_WCDMA_POINT_TO_POINT = 0x06,
     QMI_WMS_MESSAGE_FORMAT_GSM_WCDMA_BROADCAST      = 0x07,
     QMI_WMS_MESSAGE_FORMAT_MWI                      = 0x08
 } QmiWmsMessageFormat;
 
-/**
- * qmi_wms_message_format_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsMessageMode:
  * @QMI_WMS_MESSAGE_MODE_CDMA: Message sent using 3GPP2 technologies.
@@ -114,17 +95,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_MODE_CDMA      = 0x00,
     QMI_WMS_MESSAGE_MODE_GSM_WCDMA = 0x01
 } QmiWmsMessageMode;
 
-/**
- * qmi_wms_message_mode_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsNotificationType:
  * @QMI_WMS_NOTIFICATION_TYPE_PRIMARY: Primary.
@@ -135,18 +110,12 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_NOTIFICATION_TYPE_PRIMARY        = 0x00,
     QMI_WMS_NOTIFICATION_TYPE_SECONDARY_GSM  = 0x01,
     QMI_WMS_NOTIFICATION_TYPE_SECONDARY_UMTS = 0x02
 } QmiWmsNotificationType;
 
-/**
- * qmi_wms_notification_type_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI WMS Raw Send' request/response */
 
@@ -160,18 +129,12 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_CDMA_SERVICE_OPTION_AUTO = 0x00,
     QMI_WMS_CDMA_SERVICE_OPTION_6    = 0x06,
     QMI_WMS_CDMA_SERVICE_OPTION_14   = 0x0E
 } QmiWmsCdmaServiceOption;
 
-/**
- * qmi_wms_cdma_service_option_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsCdmaCauseCode:
  * @QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT: Address is valid but not yet allocated. Since 1.18.
@@ -207,7 +170,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     /* Network errors */
     QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT              = 0x00,
     QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE = 0x01,
@@ -245,32 +208,25 @@ typedef enum {
     QMI_WMS_CDMA_CAUSE_CODE_GENERAL_OTHER                               = 0x6A
 } QmiWmsCdmaCauseCode;
 
-/**
- * qmi_wms_cdma_cause_code_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsCdmaErrorClass:
- * @QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY: Temporary error.
- * @QMI_WMS_CDMA_ERROR_CLASS_PERMANENT: Permanent error.
+ * @QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY: Temporary error reported by network.
+ * @QMI_WMS_CDMA_ERROR_CLASS_PERMANENT: Permanent error reported by network.
+ * @QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY_DEVICE: Temporary error reported by device. Since 1.28.
+ * @QMI_WMS_CDMA_ERROR_CLASS_PERMANENT_DEVICE: Permanent error reported by device. Since 1.28.
  *
- * Error class when failed to send an SMS in CDMA.
+ * Error class reported from the network when failed to send an SMS in CDMA,
+ * or reported by the device when failed to process a transfer-only CDMA message.
  *
  * Since: 1.0
  */
-typedef enum {
-    QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY = 0x00,
-    QMI_WMS_CDMA_ERROR_CLASS_PERMANENT = 0x01
+typedef enum { /*< since=1.0 >*/
+    QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY        = 0x00,
+    QMI_WMS_CDMA_ERROR_CLASS_PERMANENT        = 0x01,
+    QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY_DEVICE = 0x02,
+    QMI_WMS_CDMA_ERROR_CLASS_PERMANENT_DEVICE = 0x03,
 } QmiWmsCdmaErrorClass;
 
-/**
- * qmi_wms_cdma_error_class_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsGsmUmtsRpCause:
  * @QMI_WMS_GSM_UMTS_RP_CAUSE_UNASSIGNED_NUMBER: Unassigned number.
@@ -302,7 +258,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_GSM_UMTS_RP_CAUSE_UNASSIGNED_NUMBER                    = 0x01,
     QMI_WMS_GSM_UMTS_RP_CAUSE_OPERATOR_DETERMINED_BARRING          = 0x08,
     QMI_WMS_GSM_UMTS_RP_CAUSE_CALL_BARRED                          = 0x0A,
@@ -329,12 +285,6 @@ typedef enum {
     QMI_WMS_GSM_UMTS_RP_CAUSE_INTERWORKING                         = 0x7F
 } QmiWmsGsmUmtsRpCause;
 
-/**
- * qmi_wms_gsm_umts_rp_cause_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsGsmUmtsTpCause:
  * @QMI_WMS_GSM_UMTS_TP_CAUSE_TELE_INTERWORKING_NOT_SUPPORTED: Tele interworking not supported.
@@ -368,7 +318,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_GSM_UMTS_TP_CAUSE_TELE_INTERWORKING_NOT_SUPPORTED    = 0x80,
     QMI_WMS_GSM_UMTS_TP_CAUSE_SHORT_MESSAGE_TYPE_0_NOT_SUPPORTED = 0x81,
     QMI_WMS_GSM_UMTS_TP_CAUSE_SHORT_MESSAGE_CANNOT_BE_REPLACED   = 0x82,
@@ -397,12 +347,6 @@ typedef enum {
     QMI_WMS_GSM_UMTS_TP_CAUSE_UNSPECIFIED_ERROR                  = 0xFF
 } QmiWmsGsmUmtsTpCause;
 
-/**
- * qmi_wms_gsm_umts_tp_cause_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsMessageDeliveryFailureType:
  * @QMI_WMS_MESSAGE_DELIVERY_FAILURE_TYPE_TEMPORARY: Temporary failure.
@@ -412,17 +356,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_DELIVERY_FAILURE_TYPE_TEMPORARY = 0x00,
     QMI_WMS_MESSAGE_DELIVERY_FAILURE_TYPE_PERMANENT = 0x01
 } QmiWmsMessageDeliveryFailureType;
 
-/**
- * qmi_wms_message_delivery_failure_type_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI WMS Read Raw' request/response */
 
@@ -437,19 +375,13 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_TAG_TYPE_MT_READ     = 0x00,
     QMI_WMS_MESSAGE_TAG_TYPE_MT_NOT_READ = 0x01,
     QMI_WMS_MESSAGE_TAG_TYPE_MO_SENT     = 0x02,
     QMI_WMS_MESSAGE_TAG_TYPE_MO_NOT_SENT = 0x03
 } QmiWmsMessageTagType;
 
-/**
- * qmi_wms_message_tag_type_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsMessageProtocol:
  * @QMI_WMS_MESSAGE_PROTOCOL_CDMA: CDMA.
@@ -459,17 +391,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_PROTOCOL_CDMA  = 0x00,
     QMI_WMS_MESSAGE_PROTOCOL_WCDMA = 0x01
 } QmiWmsMessageProtocol;
 
-/**
- * qmi_wms_message_protocol_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI WMS Set Routes' request/response */
 
@@ -481,16 +407,10 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_TYPE_POINT_TO_POINT = 0x00
 } QmiWmsMessageType;
 
-/**
- * qmi_wms_message_type_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsMessageClass:
  * @QMI_WMS_MESSAGE_CLASS_0: Class 0.
@@ -504,7 +424,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_MESSAGE_CLASS_0    = 0x00,
     QMI_WMS_MESSAGE_CLASS_1    = 0x01,
     QMI_WMS_MESSAGE_CLASS_2    = 0x02,
@@ -513,12 +433,6 @@ typedef enum {
     QMI_WMS_MESSAGE_CLASS_CDMA = 0x05
 } QmiWmsMessageClass;
 
-/**
- * qmi_wms_message_class_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsReceiptAction:
  * @QMI_WMS_RECEIPT_ACTION_DISCARD: Discard message.
@@ -531,7 +445,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_RECEIPT_ACTION_DISCARD          = 0x00,
     QMI_WMS_RECEIPT_ACTION_STORE_AND_NOTIFY = 0x01,
     QMI_WMS_RECEIPT_ACTION_TRANSFER_ONLY    = 0x02,
@@ -539,12 +453,6 @@ typedef enum {
     QMI_WMS_RECEIPT_ACTION_UNKNOWN          = 0xFF
 } QmiWmsReceiptAction;
 
-/**
- * qmi_wms_receipt_action_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiWmsTransferIndication:
  * @QMI_WMS_TRANSFER_INDICATION_CLIENT: Status reports transferred to the client.
@@ -553,14 +461,24 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_WMS_TRANSFER_INDICATION_CLIENT = 0x01
 } QmiWmsTransferIndication;
 
 /**
- * qmi_wms_transfer_indication_get_string:
+ * QmiWmsAckFailureCause:
+ * @QMI_WMS_ACK_FAILURE_CAUSE_NO_NETWORK_RESPONSE: No network response.
+ * @QMI_WMS_ACK_FAILURE_CAUSE_NETWORK_RELEASED_LINK: Network released link.
+ * @QMI_WMS_ACK_FAILURE_CAUSE_NOT_SENT: Not sent.
  *
- * Since: 1.0
+ * Ack failure cause.
+ *
+ * Since: 1.28
  */
+typedef enum { /*< since=1.28 >*/
+    QMI_WMS_ACK_FAILURE_CAUSE_NO_NETWORK_RESPONSE   = 0x00,
+    QMI_WMS_ACK_FAILURE_CAUSE_NETWORK_RELEASED_LINK = 0x01,
+    QMI_WMS_ACK_FAILURE_CAUSE_NOT_SENT              = 0x02,
+} QmiWmsAckFailureCause;
 
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_WMS_H_ */
